'''
Created on Nov 7, 2017

@author: Salim
'''

CONF_PARAM_NAME_SERVER_URL = "CONF.NAMESERVER.URL"
CONF_PARAM_NAME_SERVER_PORT = "CONF.NAMESERVER.PORT"

RPC_PROTOCOL = "http://"

LESS_RPC_REQUEST_PING = "/ping"
LESS_RPC_REQUEST_EXECUTE = "/execute"
LESS_RPC_REQUEST_SERVICE = "/service"
LESS_RPC_REQUEST_INFO = "/info"

HTTP_PROTOCOL = "http://"
HTTPS_PROTOCOL = "http://"

HTTP_WAIT_TIME_SHORT = 5
HTTP_WAIT_TIME_LONG = 60 * 60 * 5



